@@ -31,7 +31,8 @@ static void okayed(GtkWidget *w, int button, gpointer *d)
 {
 	if(button==0)
 	{
-		char *p=gtk_entry_get_text(GTK_ENTRY(input));
+		gchar *p = (gchar *) gtk_entry_get_text(GTK_ENTRY(input));
+
 		write(2,p, strlen(p));
 		write(2, "\n", 1);
 	}
@@ -59,6 +60,7 @@ int dialog_inputbox(const char *title, const char *prompt, int height, int width
 		GtkWidget *vbox;
 		GtkWidget *ibox;
 
+		gnome_dialog_set_default (GNOME_DIALOG (w), 0);
 		gnome_dialog_set_close(GNOME_DIALOG(w), TRUE);
 		gtk_window_set_title(GTK_WINDOW(w), title);
 
@@ -72,6 +74,7 @@ int dialog_inputbox(const char *title, const char *prompt, int height, int width
 		input = gtk_entry_new();
 		if(init)
 			gtk_entry_set_text(GTK_ENTRY(input),init);
+		gnome_dialog_editable_enters (GNOME_DIALOG (w), GTK_EDITABLE (input));
 			
 		gtk_container_set_border_width(GTK_CONTAINER(ibox), GNOME_PAD);
 			
@@ -89,6 +92,7 @@ int dialog_inputbox(const char *title, const char *prompt, int height, int width
 		gtk_signal_connect(GTK_OBJECT(w), "clicked",
 			GTK_SIGNAL_FUNC(okayed), NULL);
 		gtk_widget_show_all(w);
+		gtk_widget_grab_focus (input);
 		gtk_main();
 		return 0;
 	}
