@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.15 2001/12/05 03:30:18 kevinv Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.18 2002/01/09 02:02:32 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -22,9 +22,8 @@
 #include <string.h>
 #include <ctype.h>
 
-#define GTK_ENABLE_BROKEN
 #include <gnome.h>
-
+#include <gconf/gconf-client.h>
 #include "gdict-pref-dialog.h"
 #include "gdict-app.h"
 
@@ -49,6 +48,7 @@ static gchar *typeface_sel_names[NUM_TYPEFACES] = {
 #define NUM_TYPEFACE_COLS 2
 
 static gint gdict_pref_dialog_signals[LAST_SIGNAL] = { 0 };
+extern GConfClient *client;
 
 static void gdict_pref_dialog_init (GDictPrefDialog *pref_dialog);
 static void gdict_pref_dialog_class_init (GDictPrefDialogClass *class);
@@ -77,6 +77,10 @@ static void pref_data_cb            (dict_command_t *command, dict_res_t *res,
 static void pref_dialog_ok_cb       (GtkWidget *widget, gpointer data);
 static void pref_dialog_apply_cb    (GtkWidget *widget, gpointer data);
 static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
+static void response_cb		    (GtkDialog *dialog, gint response);
+static void server_button_cb	    (GtkButton *button, gpointer data);
+static void port_button_cb	    (GtkButton *button, gpointer data);
+static void smart_lookup_cb	    (GtkToggleButton *toggle, gpointer data);
 
 /* gdict_pref_dialog_get_type
  *
@@ -84,23 +88,29 @@ static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
  * return the type identifier code
  */
 
-guint 
+GType
 gdict_pref_dialog_get_type (void) {
-    static guint gdict_pref_dialog_type = 0;
+    static GType gdict_pref_dialog_type = 0;
+    
+    g_type_init ();
     
     if (!gdict_pref_dialog_type) {
-        GtkTypeInfo gdict_pref_dialog_info = {
-            "GDictPrefDialog",
-            sizeof (GDictPrefDialog),
+        static const GTypeInfo gdict_pref_dialog_info = {
             sizeof (GDictPrefDialogClass),
-            (GtkClassInitFunc) gdict_pref_dialog_class_init,
-            (GtkObjectInitFunc) gdict_pref_dialog_init,
+            (GBaseInitFunc) NULL,
+            (GBaseFinalizeFunc) NULL,
+            (GClassInitFunc) gdict_pref_dialog_class_init,
             NULL,
-            NULL
+            NULL,
+            sizeof (GDictPrefDialog),
+            0,
+            (GInstanceInitFunc) gdict_pref_dialog_init,
         };
         
-        gdict_pref_dialog_type = 
-            gtk_type_unique (gnome_dialog_get_type (), &gdict_pref_dialog_info);
+        gdict_pref_dialog_type = g_type_register_static (GTK_TYPE_DIALOG, 
+        					         "GDictPrefDialog", 
+        					         &gdict_pref_dialog_info,
+        					         0);
     }
     
     return gdict_pref_dialog_type;
@@ -113,205 +123,7 @@ gdict_pref_dialog_get_type (void) {
 
 static void 
 gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
-    GtkWidget *label, *alignment;
-    GtkWidget *vbox, *table, *table1;
-    GtkWidget *notebook;
-    gchar *port_str;
-    gint i;
-    
-    pref_dialog->context = NULL;
-    pref_dialog->get_db_cmd = NULL;
-    pref_dialog->get_strat_cmd = NULL;
-    
-    pref_dialog->database = gdict_pref.database;
-    pref_dialog->dfl_strat = gdict_pref.dfl_strat;
-    
-    gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Preferences"));
-    gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);
 
-    notebook = gtk_notebook_new ();
-    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (pref_dialog)->vbox), notebook, 
-                        TRUE, TRUE, 0);
-    
-    pref_dialog->table = GTK_TABLE (gtk_table_new (5, 2, FALSE));
-    gtk_container_add (GTK_CONTAINER (notebook), 
-                       GTK_WIDGET (pref_dialog->table));
-    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 8);
-    gtk_table_set_row_spacings (pref_dialog->table, 6);
-    gtk_table_set_col_spacings (pref_dialog->table, 6);
-
-    alignment = gtk_alignment_new(0, 0.5, 0, 1);
-    gtk_table_attach_defaults (pref_dialog->table, alignment, 0, 2, 2, 3);
-
-    pref_dialog->smart_lookup_btn = 
-        GTK_CHECK_BUTTON (gtk_check_button_new_with_label (_("Smart lookup")));
-    gtk_container_add (GTK_CONTAINER (alignment), 
-                       GTK_WIDGET (pref_dialog->smart_lookup_btn));
-
-    pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_table_attach_defaults (pref_dialog->table, 
-                               GTK_WIDGET (pref_dialog->server_entry), 
-                               1, 2, 0, 1);
-    
-    label = gtk_label_new (_("Server:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 0, 1);
-
-    label = gtk_label_new (_("Port:"));
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 1, 2);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-
-    pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_table_attach_defaults (pref_dialog->table, 
-                               GTK_WIDGET (pref_dialog->port_entry), 
-                               1, 2, 1, 2);
-    
-    label = gtk_label_new (_("Database:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 3, 4);
-    pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
-    gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
-    
-    label = gtk_label_new (_("Default strategy:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 4, 5);
-    pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
-    gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
-    
-    label = gtk_label_new (_("Server"));
-    gtk_notebook_set_tab_label
-	(GTK_NOTEBOOK (notebook), 
-	 gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), 
-	 label);
-    
-    gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
-    
-    table1 = gtk_table_new (1, 1, FALSE);
-    alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
-    table = gtk_table_new (NUM_TYPEFACE_ROWS + 2, NUM_TYPEFACE_COLS, FALSE);
-    gtk_table_attach (GTK_TABLE (table1), table, 0, 1, 0, 1,
-                      0, 0, 10, 10);
-    gtk_container_add (GTK_CONTAINER (alignment), table1);
-    gtk_container_add (GTK_CONTAINER (notebook), alignment);
-    
-    gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 4);
-    
-    for (i = 0; i < NUM_TYPEFACES; i++) {
-        label = gtk_label_new (_(typeface_sel_names[i]));
-        gtk_table_attach (GTK_TABLE (table), label, 
-                          (3 * (i / NUM_TYPEFACE_ROWS)), 
-                          (3 * (i / NUM_TYPEFACE_ROWS)) + 1,
-                          (i % NUM_TYPEFACE_ROWS), 
-                          (i % NUM_TYPEFACE_ROWS) + 1, GTK_FILL, 0, 5, 0);
-        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-        
-        pref_dialog->font_pickers[i] = 
-            GNOME_FONT_PICKER (gnome_font_picker_new ());
-        gtk_table_attach (GTK_TABLE (table), 
-                          GTK_WIDGET (pref_dialog->font_pickers[i]),
-                          (3 * (i / NUM_TYPEFACE_ROWS)) + 1, 
-                          (3 * (i / NUM_TYPEFACE_ROWS)) + 2,
-                          (i % NUM_TYPEFACE_ROWS), 
-                          (i % NUM_TYPEFACE_ROWS) + 1, 0, GTK_FILL, 0, 0);
-        
-        pref_dialog->color_pickers[i] = 
-            GNOME_COLOR_PICKER (gnome_color_picker_new ());
-        gtk_table_attach (GTK_TABLE (table), 
-                          GTK_WIDGET (pref_dialog->color_pickers[i]),
-                          (3 * (i / NUM_TYPEFACE_ROWS)) + 2, 
-                          (3 * (i / NUM_TYPEFACE_ROWS)) + 3,
-                          (i % NUM_TYPEFACE_ROWS), 
-                          (i % NUM_TYPEFACE_ROWS) + 1, 0, GTK_FILL, 0, 0);
-    }
-    
-    gtk_widget_show_all (table1);
-    
-    label = gtk_label_new (_("Fonts"));
-    gtk_notebook_set_tab_label
-	(GTK_NOTEBOOK (notebook), 
-	 gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), 
-	 label);
-    
-#if 0
-    if (gdict_applet_toggle) {
-        vbox = gtk_vbox_new (FALSE, 2);
-        gtk_container_add (GTK_CONTAINER (notebook), vbox);
-        gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
-        
-        alignment = gtk_alignment_new (0, 0.5, 0, 1);
-        gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
-
-        pref_dialog->applet_handle_btn = 
-            GTK_CHECK_BUTTON (gtk_check_button_new_with_label
-			      (_("Display handle bar")));
-        gtk_container_add (GTK_CONTAINER (alignment), 
-                           GTK_WIDGET (pref_dialog->applet_handle_btn));
-        
-        label = gtk_label_new (_("You have to restart GDict for these\nsettings to become active."));
-        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-        gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-        
-        gtk_widget_show_all (vbox);
-        
-        label = gtk_label_new (_("Applet"));
-        gtk_notebook_set_tab_label
-	    (GTK_NOTEBOOK (notebook), 
-	     gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 2), 
-	     label);
-    }
-#endif
-
-    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog),
-				GNOME_STOCK_BUTTON_OK);
-    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog),
-				GNOME_STOCK_BUTTON_APPLY);
-    gnome_dialog_append_button (GNOME_DIALOG (pref_dialog),
-				GNOME_STOCK_BUTTON_CANCEL);
-
-    gnome_dialog_button_connect (GNOME_DIALOG (pref_dialog), 0,
-                                 GTK_SIGNAL_FUNC (pref_dialog_ok_cb),
-                                 pref_dialog);
-    gnome_dialog_button_connect (GNOME_DIALOG (pref_dialog), 1,
-                                 GTK_SIGNAL_FUNC (pref_dialog_apply_cb),
-                                 pref_dialog);
-    gnome_dialog_button_connect (GNOME_DIALOG (pref_dialog), 2,
-                                 GTK_SIGNAL_FUNC (pref_dialog_close_cb),
-                                 pref_dialog);
-    
-    gnome_dialog_set_default (GNOME_DIALOG (pref_dialog), 1);
-    
-    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
-			gdict_pref.server);
-    port_str = g_strdup_printf("%d", (int) gdict_pref.port);
-    gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
-    g_free(port_str);
-    gtk_toggle_button_set_active
-	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn), gdict_pref.smart);
-
-#if 0
-    if (gdict_applet_toggle)
-        gtk_toggle_button_set_active
-	    (GTK_TOGGLE_BUTTON(pref_dialog->applet_handle_btn),
-	     gdict_pref.applet_handle);
-#endif
-
-    for (i = 0; i < NUM_TYPEFACES; i++) {
-        gnome_font_picker_set_font_name (pref_dialog->font_pickers[i], 
-                                         gdict_pref.typefaces[i].font_name);
-        gnome_color_picker_set_i16 (pref_dialog->color_pickers[i], 
-                                    gdict_pref.typefaces[i].color->red, 
-                                    gdict_pref.typefaces[i].color->green, 
-                                    gdict_pref.typefaces[i].color->blue, 0);
-    }
-    
-    gtk_widget_show_all (notebook);
 }
 
 /* gdict_pref_dialog_class_init
@@ -350,6 +162,101 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class)
     class->apply_changes = NULL;
 }
 
+static void
+create_dialog (GDictPrefDialog *pref_dialog)
+{
+    GtkWidget *label, *alignment;
+    GtkWidget *vbox, *table;
+    GtkWidget *button;    
+    gchar *port_str;
+    gint i;
+    
+    pref_dialog->database = gdict_pref.database;
+    pref_dialog->dfl_strat = gdict_pref.dfl_strat;
+    
+    gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Preferences"));
+    gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);    
+    vbox = GTK_DIALOG (pref_dialog)->vbox;
+
+    
+    pref_dialog->table = GTK_TABLE (gtk_table_new (5, 3, FALSE));
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), GTK_WIDGET (pref_dialog->table), TRUE, TRUE, 0);
+    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 8);
+    gtk_table_set_row_spacings (pref_dialog->table, 6);
+    gtk_table_set_col_spacings (pref_dialog->table, 6);
+
+    pref_dialog->smart_lookup_btn = 
+        GTK_CHECK_BUTTON (gtk_check_button_new_with_label (_("Smart lookup")));
+    g_signal_connect (G_OBJECT (pref_dialog->smart_lookup_btn), "toggled",
+    		      G_CALLBACK (smart_lookup_cb), pref_dialog);
+    gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
+    			       1, 3, 2, 3);
+    
+    pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());
+    gtk_table_attach_defaults (pref_dialog->table, 
+                               GTK_WIDGET (pref_dialog->server_entry), 
+                               1, 2, 0, 1);
+    
+    label = gtk_label_new (_("Server:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 0, 1);
+    
+    button = gtk_button_new_with_mnemonic (_("Set _Server"));
+    gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 0, 1);
+    g_signal_connect (G_OBJECT (button), "clicked",
+    		      G_CALLBACK (server_button_cb), pref_dialog);
+
+    label = gtk_label_new (_("Port:"));
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 1, 2);
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+
+    pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
+    gtk_table_attach_defaults (pref_dialog->table, 
+                               GTK_WIDGET (pref_dialog->port_entry), 
+                               1, 2, 1, 2);
+                               
+    button = gtk_button_new_with_mnemonic (_("Set _Port"));
+    gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 1, 2);
+    g_signal_connect (G_OBJECT (button), "clicked",
+    		      G_CALLBACK (port_button_cb), pref_dialog);
+    
+    label = gtk_label_new (_("Database:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 3, 4);
+    pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
+    gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
+    
+    label = gtk_label_new (_("Default strategy:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (pref_dialog->table, label, 0, 1, 4, 5);
+    pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
+    gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
+    
+    gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
+
+
+
+    gtk_dialog_add_button (GTK_DIALOG (pref_dialog), GTK_STOCK_OK,
+    			   GTK_RESPONSE_OK);  
+    
+    g_signal_connect (G_OBJECT (pref_dialog), "response",
+    		      G_CALLBACK (response_cb), NULL);
+
+    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
+			gdict_pref.server);
+    port_str = g_strdup_printf("%d", (int) gdict_pref.port);
+    gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
+    g_free(port_str);
+    gtk_toggle_button_set_active
+	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn), gdict_pref.smart);
+
+
+}
+
 /* gdict_pref_dialog_new
  *
  * Creates a new GDictPrefDialog object
@@ -359,6 +266,7 @@ GtkWidget *
 gdict_pref_dialog_new (dict_context_t *context) 
 {
     GDictPrefDialog *pref_dialog;
+    GtkLabel *label;
     
     /* g_return_val_if_fail (context != NULL, NULL); */
     /* the above is commented out because it prints ugly debug messages
@@ -368,9 +276,11 @@ gdict_pref_dialog_new (dict_context_t *context)
     
     pref_dialog =
 	GDICT_PREF_DIALOG (gtk_type_new (gdict_pref_dialog_get_type ()));
-    pref_dialog->context = context;
+    pref_dialog->context = context;    
+    create_dialog (pref_dialog);
     pref_dialog_reset_db (pref_dialog);
     pref_dialog_reset_strat (pref_dialog);
+   
 
     return GTK_WIDGET (pref_dialog);
 }
@@ -400,6 +310,8 @@ pref_set_db_cb (GtkWidget *widget, gpointer data)
     pref_dialog = GDICT_PREF_DIALOG (data);
     pref_dialog->database = 
         gtk_object_get_data (GTK_OBJECT (widget), "db_name");
+        
+    gconf_client_set_string (client, "/apps/gdict/database", pref_dialog->database, NULL);
 }
 
 /* pref_set_strat_cb
@@ -415,6 +327,8 @@ pref_set_strat_cb (GtkWidget *widget, gpointer data)
     pref_dialog = GDICT_PREF_DIALOG (data);
     pref_dialog->dfl_strat = 
         gtk_object_get_data (GTK_OBJECT (widget), "strat_name");
+    
+    gconf_client_set_string (client, "/apps/gdict/stratagy", pref_dialog->dfl_strat, NULL);
 }
 
 /* pref_dialog_add_db
@@ -483,7 +397,7 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         pref_dialog->db_sel = NULL;
     }
-    
+  
     pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     
     pref_dialog->get_db_cmd = dict_show_db_command_new ();
@@ -494,7 +408,7 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
     pref_dialog->database_idx = 0;
     
     pref_dialog_add_db (pref_dialog, "!", _("Search all databases"));
-    
+ 
     if (dict_command_invoke (pref_dialog->get_db_cmd,
 			     pref_dialog->context) == -1)
     {
@@ -554,81 +468,6 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
     }
 }
 
-/* pref_dialog_update_pref
- *
- * Updates global preferences structure with changes in preferences
- */
-
-static gint
-pref_dialog_update_pref (GDictPrefDialog *pref_dialog, gboolean save_prefs) {
-    gchar *server, *port;
-    gchar *old_server;
-    gint old_port;
-    const gchar *font_name;
-    gboolean smart;
-    gint i;
-    
-    server = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->server_entry), 0, -1);
-    port = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->port_entry), 0, -1);
-    smart = gtk_toggle_button_get_active
-	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn));
-    
-    if (strcmp (gdict_pref.server, server) || 
-		gdict_pref.port != atoi (port) ||
-		gdict_pref.smart != smart) {
-
-        old_server = gdict_pref.server; old_port = gdict_pref.port;
-        gdict_pref.server = g_strdup(server);
-        gdict_pref.port = atoi(port);
-        
-        /* Try connecting. If we fail, restore the old config and abort */
-        if (gdict_init_context ()) {
-			gnome_error_dialog_parented (
-				_("The server you specified could not be found."), 
-				GTK_WINDOW (gdict_app));
-			return -1;
-		}
-        
-        pref_dialog->context = context;
-        
-        g_free(old_server);
-        gdict_pref.smart = smart;
-        
-        pref_dialog_reset_db (pref_dialog);
-        pref_dialog_reset_strat (pref_dialog);
-    }
-    
-    if (server)
-    	g_free (server);
-    if (port)
-        g_free (port);
-    
-    gdict_pref.database = g_strdup (pref_dialog->database);
-    gdict_pref.dfl_strat = g_strdup (pref_dialog->dfl_strat);
-    
-    for (i = 0; i < NUM_TYPEFACES; i++) {
-        g_free(gdict_pref.typefaces[i].font_name);
-        font_name = gnome_font_picker_get_font_name(pref_dialog->font_pickers[i]);
-        gdict_pref.typefaces[i].font_name = g_strdup(font_name);
-        gdict_pref.typefaces[i].font = gnome_font_picker_get_font(pref_dialog->font_pickers[i]);
-        
-        gnome_color_picker_get_i16(pref_dialog->color_pickers[i], 
-                                   &gdict_pref.typefaces[i].color->red, 
-                                   &gdict_pref.typefaces[i].color->green, 
-                                   &gdict_pref.typefaces[i].color->blue, NULL);
-    }
-#ifdef FIXME    
-    if (gdict_applet_toggle) {
-        gdict_pref.applet_handle = 
-            gtk_toggle_button_get_active
-	              (GTK_TOGGLE_BUTTON (pref_dialog->applet_handle_btn));
-    }
-#endif    
-    if (save_prefs)
-	gdict_pref_save();
-    
-    return 0;
-}
 
 /* pref_error_cb
  *
@@ -647,7 +486,12 @@ pref_error_cb (dict_command_t *command, DictStatusCode code,
     pref_dialog = GDICT_PREF_DIALOG (data);
     
     if (code != DICT_SOCKET_ERROR) {
-        gnome_error_dialog_parented (message, GTK_WINDOW (pref_dialog));
+        GtkWidget *dialog;
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  	 "%s", message, NULL); 
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
     }
     else {
         gtk_signal_emit (GTK_OBJECT (pref_dialog),
@@ -709,10 +553,10 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
         option_menu = GTK_OPTION_MENU (gtk_option_menu_new ());
         gtk_option_menu_set_menu (option_menu, GTK_WIDGET (use_menu));
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
-        gtk_container_add (GTK_CONTAINER (alignment),
-			   GTK_WIDGET (option_menu));
-        gtk_table_attach_defaults (pref_dialog->table, alignment, 
-                                   1, 2, row, row + 1);
+        /*gtk_container_add (GTK_CONTAINER (alignment),
+			   GTK_WIDGET (option_menu));*/
+        gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (option_menu), 
+                                   1, 3, row, row + 1);
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
         
         if (command->cmd == C_SHOW_DB)
@@ -722,72 +566,122 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
     }
 }
 
-/* pref_dialog_ok_cb
- *
- * Callback issued when the Ok button is clicked
- */
-
 static void 
-pref_dialog_ok_cb (GtkWidget *widget, gpointer user_data) {
-    GDictPrefDialog *pref_dialog;
+response_cb (GtkDialog *dialog, gint response)
+{
+    gtk_widget_hide (GTK_WIDGET (dialog));
     
-    g_return_if_fail (user_data != NULL);
-    g_return_if_fail (IS_GDICT_PREF_DIALOG (user_data));
-    
-    pref_dialog = GDICT_PREF_DIALOG(user_data);
-    if (pref_dialog_update_pref(pref_dialog, TRUE)) return;
-    
-    gtk_signal_emit (GTK_OBJECT (pref_dialog),
-                     gdict_pref_dialog_signals[APPLY_CHANGES_SIGNAL]);
-    
-    gnome_dialog_close (GNOME_DIALOG (pref_dialog));
 }
 
-/* pref_dialog_apply_cb
- *
- * Callback issued when the Apply button is clicked
- */
+static void
+server_button_cb (GtkButton *button, gpointer data)
+{
+    GDictPrefDialog *pref_dialog = data;
+    gchar *server;
+    server = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->server_entry), 0, -1);
 
-static void 
-pref_dialog_apply_cb (GtkWidget *widget, gpointer user_data) {
-    GDictPrefDialog *pref_dialog;
+    if (strcmp (gdict_pref.server, server)) {
+	gchar *old_server;
+	
+        old_server = gdict_pref.server; 
+        gdict_pref.server = g_strdup(server);
+       
+        /* Try connecting. If we fail, restore the old config and abort */
+        if (gdict_init_context ()) {
+        	        GtkWidget *dialog;
+        	        
+        	        dialog = gtk_message_dialog_new (NULL,
+        	                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+        	                                         GTK_MESSAGE_ERROR,
+        	                                         GTK_BUTTONS_OK,
+        	                                         "%s",
+        	                                         _("The server you specified could not be found."));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
+			g_free (gdict_pref.server);
+			gdict_pref.server = old_server;
+			gdict_init_context ();
+			gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
+				            gdict_pref.server);
+			return;
+		}
+	else {
+        
+            pref_dialog->context = context;
+        
+            g_free (old_server);
+            
+            pref_dialog_reset_db (pref_dialog);
+            pref_dialog_reset_strat (pref_dialog);
+           
+            gconf_client_set_string (client, "/apps/gdict/server", gdict_pref.server, NULL);
+        }
+    }
     
-    g_return_if_fail (user_data != NULL);
-    g_return_if_fail (IS_GDICT_PREF_DIALOG (user_data));
-    
-    pref_dialog = GDICT_PREF_DIALOG(user_data);
-    if (pref_dialog_update_pref(pref_dialog, FALSE)) return;
-    
-    gtk_signal_emit (GTK_OBJECT (pref_dialog),
-                     gdict_pref_dialog_signals[APPLY_CHANGES_SIGNAL]);
+    if (server)
+    	g_free (server);
 }
 
-/* pref_dialog_close_cb
- *
- * Callback issued when the Close button is clicked
- */
 
 static void 
-pref_dialog_close_cb (GtkWidget *widget, gpointer user_data) {
-    GDictPrefDialog *pref_dialog;
-    gchar *old_server;
-    guint old_port;
+port_button_cb (GtkButton *button, gpointer data)
+{
+    GDictPrefDialog *pref_dialog = data;
+    gchar *port;
+    gint old_port;
     
-    g_return_if_fail (user_data != NULL);
-    g_return_if_fail (IS_GDICT_PREF_DIALOG (user_data));
+    port = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->port_entry), 0, -1);
     
-    pref_dialog = GDICT_PREF_DIALOG (user_data);
-    gtk_widget_hide (GTK_WIDGET (pref_dialog));
+    if (gdict_pref.port != atoi (port)) {
     
-    old_server = g_strdup (gdict_pref.server);
-    old_port = gdict_pref.port;
-    gdict_pref_load ();
+        old_port = gdict_pref.port;
+        gdict_pref.port = atoi (port);
+        /* Try connecting. If we fail, restore the old config and abort */
+        if (gdict_init_context ()) {
+        	        GtkWidget *dialog;
+        	        gchar *port_str;
+        	        
+        	        dialog = gtk_message_dialog_new (NULL,
+        	                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+        	                                         GTK_MESSAGE_ERROR,
+        	                                         GTK_BUTTONS_OK,
+        	                                         "%s",
+        	                                         _("The server could not be found on that port."));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
+			g_free (gdict_pref.server);
+			gdict_pref.port = old_port;
+			gdict_init_context ();
+			port_str = g_strdup_printf("%d", (int) gdict_pref.port);
+    			gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port_str);
+    			g_free(port_str);
+			return;
+		}
+	else {
+        
+            pref_dialog->context = context;
+        
+            pref_dialog_reset_db (pref_dialog);
+            pref_dialog_reset_strat (pref_dialog);
+            
+            gconf_client_set_int (client, "/apps/gdict/port", gdict_pref.port, NULL);
+        }
+    }
     
-    if (strcmp (old_server, gdict_pref.server) || old_port != gdict_pref.port)
-      gdict_init_context ();
+    g_free (port);
+}
+
+static void 
+smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
+{
+    GDictPrefDialog *pref_dialog = data;
+    gboolean toggled;
     
-    gtk_signal_emit (GTK_OBJECT (pref_dialog),
-                     gdict_pref_dialog_signals[APPLY_CHANGES_SIGNAL]);
+    toggled = gtk_toggle_button_get_active (toggle);
     
-    gnome_dialog_close (GNOME_DIALOG (pref_dialog));
+    if (toggled != gdict_pref.smart) {
+        gconf_client_set_bool (client, "/apps/gdict/smart", toggled, NULL);
+    }
+    
+
 }
