@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.4 2001/06/05 11:33:02 kmaraas Exp $ */
+/* $Id: gdict-speller.c,v 1.10 2001/12/14 00:38:59 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -31,8 +31,8 @@
 #endif
 
 #include "gdict-speller.h"
-#include "gdict-app.h"
 #include "gdict-pref.h"
+#include "gdict-app.h"
 
 enum {
     WORD_LOOKUP_START_SIGNAL,
@@ -63,11 +63,14 @@ static void spell_word_data_cb    (dict_command_t *command, dict_res_t *res,
                                    gpointer data);
 static void spell_strat_data_cb   (dict_command_t *command, dict_res_t *res,
                                    gpointer data);
-static void speller_spell_cb      (GtkWidget *widget, gpointer data);
-static void speller_lookup_cb     (GtkWidget *widget, gpointer data);
-static void speller_close_cb      (GtkWidget *widget, gpointer data);
-static void word_select_cb        (GtkCList *clist, gint row, gint column,
-                                   GdkEventButton *event, gpointer data);
+static void spell_response_cb	  (GtkDialog *dialog, gint id, gpointer data);
+static void spell_button_pressed  (GtkButton *button, gpointer data);
+static void row_selected_cb       (GtkTreeSelection *selection, gpointer data);
+static void row_activated_cb      (GtkTreeView *tree, GtkTreePath *path, 
+				   GtkTreeViewColumn *column, gpointer data);
+static void spell_entry_cb	  (GtkEntry *entry, gpointer data);
+static void speller_lookup        (GDictSpeller *speller);
+
 
 /* gdict_speller_get_type
  *
@@ -75,23 +78,25 @@ static void word_select_cb        (GtkCList *clist, gint row, gint column,
  * return the type identifier code
  */
 
-guint 
+GType
 gdict_speller_get_type (void) {
-    static guint gdict_speller_type = 0;
+    static GType gdict_speller_type = 0;
     
     if (!gdict_speller_type) {
-        GtkTypeInfo gdict_speller_info = {
-            "GDictSpeller",
-            sizeof (GDictSpeller),
+        static const GTypeInfo gdict_speller_info = {
             sizeof (GDictSpellerClass),
-            (GtkClassInitFunc) gdict_speller_class_init,
-            (GtkObjectInitFunc) gdict_speller_init,
-            (GtkArgSetFunc) NULL,
-            (GtkArgGetFunc) NULL
+            NULL,
+            NULL,
+            (GClassInitFunc) gdict_speller_class_init,
+	    NULL,
+	    NULL,
+ 	    sizeof (GDictSpeller),
+	    0,
+            (GInstanceInitFunc) gdict_speller_init
         };
         
         gdict_speller_type = 
-            gtk_type_unique (gnome_dialog_get_type (), &gdict_speller_info);
+            g_type_register_static (GTK_TYPE_DIALOG, "GDictSpeller", &gdict_speller_info, 0);
     }
     
     return gdict_speller_type;
@@ -104,7 +109,11 @@ gdict_speller_get_type (void) {
 
 static void 
 gdict_speller_init (GDictSpeller *speller) {
-    GtkWidget *label, *scrolled_win;
+    GtkWidget *label, *button, *scrolled_win;
+    GtkListStore *model;
+    GtkTreeViewColumn *column;
+    GtkTreeSelection *selection;
+    GtkCellRenderer *cell;
     
     speller->context = NULL;
     speller->get_strat_cmd = NULL;
@@ -115,14 +124,16 @@ gdict_speller_init (GDictSpeller *speller) {
     gtk_table_set_row_spacings (speller->table, 5);
     gtk_table_set_col_spacings (speller->table, 5);
     
-    label = gtk_label_new (_("Word:"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-    gtk_table_attach_defaults (speller->table, label, 0, 1, 0, 1);
+    button = gtk_button_new_with_mnemonic (_("_Spell"));
+    gtk_table_attach_defaults (speller->table, button, 0, 1, 0, 1);
+    g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (spell_button_pressed),
+    		      speller);
     
     speller->word_entry = GTK_ENTRY (gtk_entry_new ());
     gtk_table_attach_defaults (speller->table, 
 		               GTK_WIDGET (speller->word_entry), 1, 2, 0, 1);
+    g_signal_connect (G_OBJECT (speller->word_entry), "activate",
+    	  	      G_CALLBACK (spell_entry_cb), speller);
     
     label = gtk_label_new (_("Search Strategy:"));
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
@@ -138,32 +149,40 @@ gdict_speller_init (GDictSpeller *speller) {
     gtk_table_attach (speller->table, scrolled_win, 0, 2, 2, 3, 
                       GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 5);
     
-    speller->word_sel = GTK_CLIST (gtk_clist_new (1));
-    gtk_clist_column_titles_hide (speller->word_sel);
-    gtk_clist_set_selection_mode (speller->word_sel, GTK_SELECTION_SINGLE);
-    gtk_signal_connect (GTK_OBJECT (speller->word_sel), "select-row",
-                        GTK_SIGNAL_FUNC (word_select_cb), speller);
-    gtk_container_add (GTK_CONTAINER (scrolled_win), 
-                       GTK_WIDGET (speller->word_sel));
+    model = gtk_list_store_new (1, G_TYPE_STRING);
     
-    gnome_dialog_append_buttons (GNOME_DIALOG (speller),
-                                 _("Find Words..."),
-                                 _("Lookup Word..."),
-                                 GNOME_STOCK_BUTTON_CLOSE,
-                                 NULL);
+    speller->word_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (speller->word_list), FALSE);
+    g_object_unref (G_OBJECT (model));
     
-    gnome_dialog_set_default (GNOME_DIALOG (speller), 0);
+    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (speller->word_list));
+    g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (row_selected_cb),
+    		      speller);
     
-    gnome_dialog_button_connect (GNOME_DIALOG (speller), 0,
-                        GTK_SIGNAL_FUNC (speller_spell_cb), speller);
-    gnome_dialog_button_connect (GNOME_DIALOG (speller), 1,
-                        GTK_SIGNAL_FUNC (speller_lookup_cb), speller);
-    gnome_dialog_button_connect (GNOME_DIALOG (speller), 2,
-                        GTK_SIGNAL_FUNC (speller_close_cb), speller);
+    cell = gtk_cell_renderer_text_new ();
+    column = gtk_tree_view_column_new_with_attributes ("words", 
+    						       cell,
+    						       "text", 0,
+    						       NULL);
+    gtk_tree_view_column_set_sort_column_id (column, 0);
+    
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
+                                          0,GTK_SORT_ASCENDING); 
+                                          
+    gtk_tree_view_append_column (GTK_TREE_VIEW (speller->word_list), column);
+    gtk_container_add (GTK_CONTAINER (scrolled_win), speller->word_list);
+
+    gtk_dialog_add_buttons (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+    		                                  _("_Look Up"), 100,
+    		                                  NULL);
+    g_signal_connect (G_OBJECT (speller->word_list), "row_activated",
+    		      G_CALLBACK (row_activated_cb), speller);	                                  
+    g_signal_connect (G_OBJECT (speller), "response", G_CALLBACK (spell_response_cb),
+    		      speller);
     gtk_window_set_title (GTK_WINDOW (speller), _("Spell checker"));
-    
-    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (speller)->vbox),
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox),
                         GTK_WIDGET (speller->table), 5, TRUE, TRUE);
+                         
     gtk_widget_show_all (GTK_WIDGET (speller->table));
 }
 
@@ -180,31 +199,27 @@ gdict_speller_class_init (GDictSpellerClass *class) {
     object_class = GTK_OBJECT_CLASS (class);
 
     gdict_speller_signals[WORD_LOOKUP_START_SIGNAL] =
-        gtk_signal_new ("word_lookup_start", GTK_RUN_FIRST, object_class->type,
+        gtk_signal_new ("word_lookup_start", GTK_RUN_FIRST, GTK_CLASS_TYPE (object_class),
                         GTK_SIGNAL_OFFSET (GDictSpellerClass, word_lookup_start),
                         gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
     
     gdict_speller_signals[WORD_LOOKUP_DONE_SIGNAL] =
-        gtk_signal_new ("word_lookup_done", GTK_RUN_FIRST, object_class->type,
+        gtk_signal_new ("word_lookup_done", GTK_RUN_FIRST, GTK_CLASS_TYPE (object_class),
                         GTK_SIGNAL_OFFSET (GDictSpellerClass, word_lookup_done),
                         gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
     
     gdict_speller_signals[WORD_NOT_FOUND_SIGNAL] =
-        gtk_signal_new ("word_not_found", GTK_RUN_FIRST, object_class->type,
+        gtk_signal_new ("word_not_found", GTK_RUN_FIRST, GTK_CLASS_TYPE (object_class),
                         GTK_SIGNAL_OFFSET (GDictSpellerClass, word_not_found),
                         gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
     
     gdict_speller_signals[SOCKET_ERROR_SIGNAL] =
-        gtk_signal_new ("socket_error", GTK_RUN_FIRST, object_class->type,
+        gtk_signal_new ("socket_error", GTK_RUN_FIRST, GTK_CLASS_TYPE (object_class),
                         GTK_SIGNAL_OFFSET (GDictSpellerClass, socket_error),
-                        gtk_marshal_NONE__STRING, GTK_TYPE_NONE, 1,
+                        gtk_marshal_VOID__STRING, GTK_TYPE_NONE, 1,
                         GTK_TYPE_STRING);
     
-    gtk_object_class_add_signals (object_class, gdict_speller_signals,
-                                  LAST_SIGNAL);
-    
-    parent_class = gtk_type_class (gnome_dialog_get_type ());
-
+    parent_class = g_type_class_peek_parent (class);
     class->word_lookup_done = NULL;
     class->word_not_found = NULL;
 
@@ -237,10 +252,11 @@ gdict_speller_new (dict_context_t *context) {
 
 void
 gdict_speller_destroy (GDictSpeller *speller) {
+
     g_free (speller->database);
     dict_command_destroy (speller->get_strat_cmd);
     dict_command_destroy (speller->spell_cmd);
-    GTK_OBJECT_CLASS (parent_class)->destroy (GTK_OBJECT (speller));
+    
 }
 
 /* gdict_speller_lookup
@@ -296,11 +312,13 @@ gdict_speller_lookup (GDictSpeller *speller, gchar *text) {
 
 void 
 gdict_speller_clear (GDictSpeller *speller) {
+    GtkTreeModel *model;
     g_return_if_fail (speller != NULL);
     g_return_if_fail (IS_GDICT_SPELLER (speller));
     
     gtk_entry_set_text (speller->word_entry, "");
-    gtk_clist_clear (speller->word_sel);
+    model = gtk_tree_view_get_model (GTK_TREE_VIEW (speller->word_list));
+    gtk_list_store_clear (GTK_LIST_STORE (model));
     speller->current_word = NULL;
     
     if (speller->spell_cmd) {
@@ -414,9 +432,14 @@ spell_error_cb (dict_command_t *command, DictStatusCode code,
     speller = GTK_WINDOW (data);
     
     if (code != DICT_SOCKET_ERROR) {
+        GtkWidget *dialog;
         string = g_strdup_printf (_("Error invoking query: %s"), message);
-        gnome_error_dialog_parented (string, speller);
-        
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  	 "%s", string, NULL); 
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+        g_free (string);
         if (command->cmd == C_MATCH)
           gtk_signal_emit (GTK_OBJECT (speller), 
                            gdict_speller_signals[WORD_LOOKUP_DONE_SIGNAL]);
@@ -434,7 +457,13 @@ spell_error_cb (dict_command_t *command, DictStatusCode code,
 
 static void 
 speller_add_word (GDictSpeller *speller, gchar *word) {
-    gtk_clist_append (speller->word_sel, &word);
+    GtkTreeIter iter;
+    GtkTreeModel *model;
+    
+    model = gtk_tree_view_get_model (GTK_TREE_VIEW (speller->word_list));
+    
+    gtk_list_store_insert (GTK_LIST_STORE (model), &iter, 0);
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, word, -1);
     
     if (!speller->current_word) speller->current_word = word;
 }
@@ -554,23 +583,82 @@ spell_strat_status_cb (dict_command_t *command, DictStatusCode code,
     }
 }
 
-/* speller_spell_cb
- *
- * Looks up the currently selected word
- */
+static void
+spell_response_cb (GtkDialog *dialog, gint id, gpointer data) {
+	GDictSpeller *speller;
+	
+	g_return_if_fail (data);
+	speller = GDICT_SPELLER (data);
+	
+	switch (id) {
+	case GTK_RESPONSE_DELETE_EVENT:
+	case GTK_RESPONSE_CLOSE:
+		gtk_widget_hide (GTK_WIDGET (dialog));
+		break;
+	case 100:
+		speller_lookup (speller);
+		break;
+	default:
+		break;
+	}
+	
+}
 
 static void
-speller_spell_cb (GtkWidget *widget, gpointer data) {
+spell_button_pressed (GtkButton *button, gpointer data) {
     GDictSpeller *speller;
     gchar *text;
     
     g_return_if_fail (data != NULL);
     
     speller = GDICT_SPELLER (data);
-    text = gtk_entry_get_text (speller->word_entry);
+    text = gtk_editable_get_chars (GTK_EDITABLE (speller->word_entry), 0, -1);
     gtk_editable_select_region (GTK_EDITABLE (speller->word_entry), 0,
                                 strlen (text));
     gdict_speller_lookup (speller, text);
+    if (text)
+    	g_free (text);
+
+}
+
+static void
+row_selected_cb (GtkTreeSelection *selection, gpointer data) {
+    GDictSpeller *speller;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    gchar *word;
+    g_return_if_fail (data != NULL);
+    
+    speller = GDICT_SPELLER (data);
+    
+    if (!gtk_tree_selection_get_selected (selection, NULL, &iter))
+    	return;
+    
+    model = gtk_tree_view_get_model (GTK_TREE_VIEW (speller->word_list));
+    gtk_tree_model_get (model, &iter, 0, &word, -1);
+    speller->current_word = g_strdup (word);
+
+}    
+
+static void
+row_activated_cb (GtkTreeView *tree, GtkTreePath *path, GtkTreeViewColumn *column,
+		  gpointer data) {
+    GDictSpeller *speller;
+    
+    g_return_if_fail (data != NULL);
+    speller = GDICT_SPELLER (data);
+    
+    speller_lookup (speller);
+    
+}
+
+static void
+spell_entry_cb (GtkEntry *entry, gpointer data) {
+        
+    g_return_if_fail (data != NULL);
+    
+    spell_button_pressed (NULL, data);
+    
 }
 
 /* speller_lookup_cb
@@ -579,12 +667,7 @@ speller_spell_cb (GtkWidget *widget, gpointer data) {
  */
 
 static void
-speller_lookup_cb (GtkWidget *widget, gpointer data) {
-    GDictSpeller *speller;
-    
-    g_return_if_fail (data != NULL);
-    
-    speller = GDICT_SPELLER (data);
+speller_lookup (GDictSpeller *speller) {
     
     if (!speller->current_word) return;
     
@@ -594,36 +677,3 @@ speller_lookup_cb (GtkWidget *widget, gpointer data) {
     gdict_app_do_lookup (speller->current_word);
 }
 
-/* speller_close_cb
- *
- * Closes the speller dialog
- */
-
-static void
-speller_close_cb (GtkWidget *widget, gpointer data) {
-    GDictSpeller *speller;
-    
-    g_return_if_fail (data != NULL);
-    
-    speller = GDICT_SPELLER (data);
-    gnome_dialog_close (GNOME_DIALOG (speller));
-}
-
-/* word_select_cb
- *
- * Callback invoked when a word is selected in the speller
- */
-
-static void
-word_select_cb (GtkCList *clist, gint row, gint column, GdkEventButton *event,
-                gpointer data)
-{
-    GDictSpeller *speller;
-    GList *current_row;
-    
-    if (event->button == 1) {
-        speller = GDICT_SPELLER (data);
-        current_row = g_list_nth (speller->spell_cmd->res_list, row);
-        speller->current_word = ((dict_res_t *) current_row->data)->desc;
-    }
-}
