@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.19 2001/06/12 08:20:49 jirka Exp $ */
+/* $Id: main.c,v 1.26 2002/01/09 02:02:32 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -20,7 +20,6 @@
 #include <assert.h>
 
 #include <gnome.h>
-#include <applet-widget.h>
 #include <libgnomeui/gnome-window-icon.h>
 
 #include "dict.h"
@@ -28,6 +27,7 @@
 #include "gdict-applet.h"
 #include "gdict-app.h"
 
+
 static gint save_yourself_cb (GnomeClient       *client,
                               gint               phase,
                               GnomeRestartStyle  save_style,
@@ -41,8 +41,7 @@ static gint save_yourself_cb (GnomeClient       *client,
     gint argc = 1;
 
     argv[0] = (gchar *)client_data;
-    if (gdict_applet_toggle)
-        argv[argc++] = "-a";
+
     if ((word = gdict_defbox_get_word(defbox)) != NULL)
         argv[argc++] = word;
 
@@ -55,68 +54,53 @@ static gint save_yourself_cb (GnomeClient       *client,
 int main (int argc, char *argv[])
 {
     gint i;
-	GDictApplet * applet = NULL;
+    GDictApplet * applet = NULL;
+    GnomeClient *client;
+
+    
 
     static struct poptOption args[] = {
         {"noapplet", 'a', POPT_ARG_NONE, 0, 0, "Startup without applet support", NULL},
         {NULL, 0, 0, NULL, 0, NULL, NULL}
     };
 
-    bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-    textdomain (PACKAGE);
+    bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+    textdomain(GETTEXT_PACKAGE);
 
-    gdict_applet_toggle = TRUE;
-    for (i = 0;  i < argc;  i++)
-        if (!strcmp(argv[i], "--noapplet")|| !strcmp(argv[i], "-a"))
-            gdict_applet_toggle = FALSE;
-
-    if (!gdict_applet_toggle) {
-        GnomeClient *client;
-
-        gnome_init_with_popt_table ("gdict", VERSION, argc, argv,
+    gnome_init_with_popt_table ("gdict", VERSION, argc, argv,
                                     args, 0, NULL);
 
-        if ((client = gnome_master_client()) != NULL)
+    if ((client = gnome_master_client()) != NULL)
             gtk_signal_connect (GTK_OBJECT(client), "save_yourself",
                                 GTK_SIGNAL_FUNC(save_yourself_cb),
 				(gpointer) argv[0]);
-    } else {
-        applet_widget_init("gdict", VERSION, argc, argv,
-                           args, 0, NULL );
-    }
-
+    
+    
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
-    gdict_app_create ();
+    gdict_app_create (FALSE);
     gdict_pref_load ();
-    if ((gdict_init_context () < 0) && (gdict_applet_toggle == FALSE))
+    if (gdict_init_context () < 0)
       {
-            GtkWidget *dialog = gnome_error_dialog (_("Couldn't start the dictionary; most likely, http://www.dict.org could not be contacted."));
-            gnome_dialog_run (GNOME_DIALOG (dialog));
-	    return 1;
+            GtkWidget *dialog;
+            
+            dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  	     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  	     "%s", _("The server could not be contacted. \nIf you are not connected to the internet please do so."), NULL); 
+	    gtk_dialog_run (GTK_DIALOG (dialog));
+	    gtk_widget_destroy (dialog);
       }
-    /* If we can not find the context then we may as well just quit
-     * since nothing is usable anymore. But not if we're an applet */
     defbox->context = context;
 
-    if (gdict_applet_toggle)
-        applet = gdict_applet_create();
-
-    if (!gdict_applet_toggle)
-        for (i = 1;  i < argc;  i++)
+    for (i = 1;  i < argc;  i++)
             if (argv[i][0] != '-') {
                 gdict_defbox_lookup(defbox, argv[i]);
                 break;
             }
 
-    if (!gdict_applet_toggle) {
-        gtk_widget_show(gdict_app);
-        gtk_main();
-    } else {
-        applet_widget_gtk_main();
-		gdict_applet_delete(applet);
-    }
-
-    gdict_pref_save();
+    gtk_widget_show(gdict_app);
+    gtk_main();
+    
     dict_context_destroy (context); /* FIXME */
 
     return 0;
