@@ -21,20 +21,9 @@ static gchar *file_icon = NULL;
 static gchar *folder_icon = NULL;
 static gchar *compress_icon = NULL;
 static gchar *tar_prog = NULL;
-static gchar *sh_prog = NULL;
-static gchar *gzip_prog = NULL;
-static gchar *tarstr = NULL;
-static gchar *filestr = NULL;
-static gchar *gzipstr = NULL;
 static gchar *filename = NULL;
 static pid_t temporary_pid = 0;
 static gchar *temporary_file = NULL;
-struct poptOption options;
-
-static GtkWidget *create_archive_widget=NULL;
-static GtkWidget *remove_widget=NULL;
-static GtkWidget *clear_widget=NULL;
-static GtkWidget *selectall_widget=NULL;
 
 #define ERRDLG(error) gtk_message_dialog_new (GTK_WINDOW(app), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error);
 #define ERRDLGP(error,parent) gtk_message_dialog_new (GTK_WINDOW(parent), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, error);
@@ -72,17 +61,6 @@ free_file (File *f)
 	g_free (f);
 }
 
-static void 
-cleanup_tmpstr (void)
-{
-	g_free(tarstr);
-	tarstr = NULL;
-	g_free(filestr);
-	filestr = NULL;
-	g_free(gzipstr);
-	gzipstr = NULL;
-}
-
 static char *
 make_temp_dir (void)
 {
@@ -117,8 +95,6 @@ query_dialog (const gchar *msg)
 
 	response = gtk_dialog_run (GTK_DIALOG (req));
 
-	gtk_widget_destroy(req);
-
 	if (response == GTK_RESPONSE_YES)
 		return TRUE;
 	else /* this includes -1 which is "destroyed" */
@@ -130,7 +106,7 @@ update_status (void)
 {
 	if (number_of_files > 0 || number_of_dirs > 0) {
 		gchar *msg;
-		msg = g_strdup_printf (_("Number of files: %d\nNumber of folders: %d"),
+		msg = g_strdup_printf (_("Number of files: %d\nNuber of folders: %d"),
 				       number_of_files, number_of_dirs);
 		gtk_label_set_text (GTK_LABEL (status_label), msg);
 		g_free (msg);
@@ -161,9 +137,6 @@ remove_pos (gint pos)
 
 	if (number_of_files + number_of_dirs <= 0) {
 		gtk_widget_set_sensitive (compress_button, FALSE);
-		gtk_widget_set_sensitive (create_archive_widget, FALSE);
-		gtk_widget_set_sensitive (clear_widget, FALSE);
-		gtk_widget_set_sensitive (selectall_widget, FALSE);
 	}
 
 	update_status ();
@@ -182,7 +155,7 @@ make_argv_fe (gpointer key, gpointer value, gpointer user_data)
 	struct argv_adder *argv_adder = user_data;
 	gchar *file = g_build_filename ((argv_adder->link_dir), (f->base_name), NULL);
 
-	argv_adder->argv[argv_adder->pos ++] = g_strconcat ("\"", f->base_name, "\"", NULL);
+	argv_adder->argv[argv_adder->pos ++] = f->base_name;
 
 	/* FIXME: catch errors */
 	symlink (f->name, file);
@@ -224,39 +197,20 @@ create_archive (const gchar *fname,
 	gboolean status = TRUE;
 	pid_t pid;
 	struct argv_adder argv_adder;
-	gchar *tmpfname = NULL;
 
 	if (dir == NULL)
 		argv_adder.link_dir = make_temp_dir ();
 	else
 		argv_adder.link_dir = (gchar *)dir;
 
-	/* Added code for appending .tar.gz to archive file */
-	tmpfname = g_strstr_len ((gchar *)fname, strlen((gchar *)fname), ".tar.gz");
-	if (tmpfname == NULL)
-		tmpfname = g_strstr_len ((gchar *)fname, strlen((gchar *)fname), ".tgz");
-	if (tmpfname != NULL) {
-		if (!((g_ascii_strcasecmp(tmpfname, ".tar.gz") == 0) || (g_ascii_strcasecmp(tmpfname, ".tgz") == 0)))
-			fname = g_strconcat ((gchar *)fname, ".tar.gz", NULL);
-	} else {
-		fname = g_strconcat ((gchar *)fname, ".tar.gz", NULL);
-	}
-
-        /* Since tar -z option is not available in Solaris, doing tar & gzip */
-
 	argv_adder.argv = g_new (gchar *, number_of_files + number_of_dirs + 4);
-	argv_adder.pos = 0;
+	argv_adder.argv[number_of_files + number_of_dirs + 3] = NULL;
+	argv_adder.argv[0] = tar_prog;
+	argv_adder.argv[1] = "-chzf";
+	argv_adder.argv[2] = (gchar *)fname;
+	argv_adder.pos = 3;
+
 	g_hash_table_foreach (file_ht, make_argv_fe, &argv_adder);
-	argv_adder.argv[argv_adder.pos ++] = NULL;
-
-	tarstr = g_strconcat(tar_prog, " -chf - ", NULL);
-	filestr = g_strjoinv(" ", argv_adder.argv);
-	gzipstr = g_strconcat(" | ", gzip_prog, " - > ", (gchar *)fname, NULL);
-
-	argv_adder.argv[0] = sh_prog;
-	argv_adder.argv[1] = "-c";
-	argv_adder.argv[2] = g_strconcat(tarstr, filestr, gzipstr, NULL);	
-	argv_adder.argv[3] = NULL;
 
 	/* FIXME: get error output, check for errors, etc... */
 
@@ -273,9 +227,8 @@ create_archive (const gchar *fname,
 		umask (022);
 		/* FIXME: handler errors */
 		chdir (argv_adder.link_dir);
-		execv (sh_prog, argv_adder.argv);
+		execv (tar_prog, argv_adder.argv);
 		fprintf (stderr, _("Cannot run tar/gtar"));
-		cleanup_tmpstr ();
 		_exit (1);
 	}
 
@@ -293,7 +246,7 @@ create_archive (const gchar *fname,
 	}
 
 	g_free (argv_adder.argv);
-	cleanup_tmpstr ();
+
 	return status;
 }
 
@@ -416,10 +369,6 @@ static void
 about_cb (GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about = NULL;
-	GdkPixbuf	 *pixbuf;
-	GError		 *error = NULL;
-	gchar		 *file;
-	
 	gchar *authors[] = {
 		"George Lebl <jirka@5z.com>",
 		NULL
@@ -428,39 +377,23 @@ about_cb (GtkWidget *widget, gpointer data)
 		NULL
 	};
 	/* Translator credits */
-	gchar *translator_credits = _("translator_credits");
+	gchar *translator_credits = _("");
 
 	if (about != NULL) {
 		gtk_widget_show_now (about);
 		gdk_window_raise (about->window);
 		return;
 	}
-	
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-			"document-icons/gnome-compressed.png", FALSE, NULL);
-	pixbuf = gdk_pixbuf_new_from_file (file, &error);
-	
-	if (error) {
-		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-		g_error_free (error);
-	}
-	g_free (file);
-	
-	about = gnome_about_new (_("GNOME Archive Generator"), VERSION,
+	about = gnome_about_new (_("The GNOME Archive Generator"), VERSION,
 				 "(C) 2001 George Lebl",
 				 _("Drag files in to make archives"),
 				 (const gchar **)authors,
 				 (const gchar **)documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 pixbuf);
-				 
-	if (pixbuf) {
-		gdk_pixbuf_unref (pixbuf);
-	}			 
-	
-	g_signal_connect (G_OBJECT (about), "destroy",
-			  G_CALLBACK (gtk_widget_destroyed),
-			  &about);
+				 (const gchar *)translator_credits,
+				 NULL);
+	g_signal_connect (GTK_OBJECT (about), "destroy",
+			    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+			    &about);
 	gtk_widget_show (about);
 }
 
@@ -496,31 +429,9 @@ clear_cb (GtkWidget *w, gpointer data)
 	number_of_files = number_of_dirs = 0;
 	gnome_icon_list_clear (GNOME_ICON_LIST (icon_list));
 	gtk_widget_set_sensitive (compress_button, FALSE);
-	gtk_widget_set_sensitive (create_archive_widget, FALSE);
-	gtk_widget_set_sensitive (remove_widget, FALSE);
-	gtk_widget_set_sensitive (clear_widget, FALSE);
-	gtk_widget_set_sensitive (selectall_widget, FALSE);
 	update_status ();
 }
 
-static void
-icon_select_cb (GnomeIconList *iconlist,
-		gint arg1,
-		GdkEvent *event,
-		gpointer user_data)
-{
-	gtk_widget_set_sensitive (remove_widget, TRUE);
-}
-
-static void
-icon_unselect_cb (GnomeIconList *iconlist,
-		  gint arg1,
-		  GdkEvent *event,
-		  gpointer user_data) 
-{
-	gtk_widget_set_sensitive (remove_widget, FALSE);
-}
-
 static void
 remove_cb (GtkWidget *w, gpointer data)
 {
@@ -533,13 +444,6 @@ remove_cb (GtkWidget *w, gpointer data)
 		list = gnome_icon_list_get_selection
 			(GNOME_ICON_LIST (icon_list));
 	}
-
-	if (number_of_files + number_of_dirs <= 0) {
-		gtk_widget_set_sensitive (compress_button, FALSE);
-		gtk_widget_set_sensitive (create_archive_widget, FALSE);
-		gtk_widget_set_sensitive (clear_widget, FALSE);
-		gtk_widget_set_sensitive (selectall_widget, FALSE);
-	}
 }
 
 static void
@@ -589,12 +493,12 @@ archive_cb (GtkWidget *w, gpointer data)
 	if (filename != NULL)
 		gtk_file_selection_set_filename (fsel, filename);
 
-	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
-			  G_CALLBACK (save_ok), fsel);
-	g_signal_connect_swapped
-		(G_OBJECT (fsel->cancel_button), "clicked",
-		 G_CALLBACK (gtk_widget_destroy), 
-		 fsel);
+	g_signal_connect (GTK_OBJECT (fsel->ok_button), "clicked",
+			    GTK_SIGNAL_FUNC (save_ok), fsel);
+	gtk_signal_connect_full
+		(GTK_OBJECT (fsel->cancel_button), "clicked",
+		 GTK_SIGNAL_FUNC (gtk_widget_destroy), 
+		 GTK_OBJECT (fsel));
 
 	gtk_window_set_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
 
@@ -676,9 +580,6 @@ add_file (const gchar *file)
 	}
 
 	gtk_widget_set_sensitive (compress_button, TRUE);
-	gtk_widget_set_sensitive (create_archive_widget, TRUE);
-	gtk_widget_set_sensitive (clear_widget, TRUE);
-	gtk_widget_set_sensitive (selectall_widget, TRUE);
 
 	f = g_new0 (File, 1);
 	f->type = type;
@@ -735,12 +636,12 @@ add_cb (GtkWidget *w, gpointer data)
 	if (filename != NULL)
 		gtk_file_selection_set_filename (fsel, filename);
 
-	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
-			  G_CALLBACK (add_ok), fsel);
-	g_signal_connect_swapped
-		(G_OBJECT (fsel->cancel_button), "clicked",
-		 G_CALLBACK (gtk_widget_destroy), 
-		 fsel);
+	g_signal_connect (GTK_OBJECT (fsel->ok_button), "clicked",
+			    GTK_SIGNAL_FUNC (add_ok), fsel);
+	gtk_signal_connect_full
+		(GTK_OBJECT (fsel->cancel_button), "clicked",
+		 GTK_SIGNAL_FUNC (gtk_widget_destroy), 
+		 GTK_OBJECT (fsel));
 
 	gtk_window_set_position (GTK_WINDOW (fsel), GTK_WIN_POS_MOUSE);
 
@@ -797,77 +698,27 @@ drag_data_get (GtkWidget          *widget,
 				8, string, strlen (string)+1);
 	g_free (string);
 }
-GtkWidget*
-archive_button_new_with_image (const gchar* text, const gchar* image_path)
-{
-        GtkWidget *button;
-        GtkStockItem item;
-        GtkWidget *label;
-        GtkWidget *image;
-        GtkWidget *hbox;
-        GtkWidget *align;
-
-        button = gtk_button_new ();
-
-        if (GTK_BIN (button)->child)
-                gtk_container_remove (GTK_CONTAINER (button),
-                                      GTK_BIN (button)->child);
-
-	if (image) {
-                label = gtk_label_new_with_mnemonic (text);
-
-                gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-
-                image = gtk_image_new_from_file (image_path);
-                hbox = gtk_hbox_new (FALSE, 2);
-
-                align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-
-                gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-                gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-                gtk_container_add (GTK_CONTAINER (button), align);
-                gtk_container_add (GTK_CONTAINER (align), hbox);
-                gtk_widget_show_all (align);
-
-                return button;
-        }
-
-        label = gtk_label_new_with_mnemonic (text);
-        gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-
-        gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
-
-        gtk_widget_show (label);
-        gtk_container_add (GTK_CONTAINER (button), label);
-
-        return button;
-}
-
 
 /* Menus */
 static GnomeUIInfo file_menu[] = {
-        GNOMEUIINFO_ITEM_STOCK 
-		(N_("_Add file or folder..."),
-                 N_("Add a file or folder to archive"),
-                 add_cb, GTK_STOCK_DND_MULTIPLE),
-
-	{ GNOME_APP_UI_ITEM, N_("_Create archive..."), N_("Create a new archive from the items"), 
-	(gpointer) archive_cb, NULL, NULL, GNOME_APP_PIXMAP_FILENAME, "document-icons/gnome-compressed.png", 
-	0, (GdkModifierType) 0, NULL },
-
+	GNOMEUIINFO_ITEM_NONE
+		(N_("Add file or folder..."),
+		 N_("Add a file or folder to the archive"),
+		 add_cb),
+	GNOMEUIINFO_ITEM_NONE
+		(N_("Create archive..."),
+		 N_("Create a new archive from the items"),
+		 archive_cb),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_MENU_QUIT_ITEM (quit_cb, NULL),
+	GNOMEUIINFO_MENU_EXIT_ITEM (quit_cb, NULL),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo edit_menu[] = {
-	GNOMEUIINFO_ITEM_NONE (N_("_Remove"),
-			       N_("Remove the selected item"),
+	GNOMEUIINFO_ITEM_NONE (N_("Remove"),
+			       N_("Remove the selected item(s)"),
 			       remove_cb),
-	GNOMEUIINFO_ITEM_NONE (N_("R_emove All"),
-			       N_("Remove all items"),
-			       clear_cb),
+	GNOMEUIINFO_MENU_CLEAR_ITEM (clear_cb, NULL),
 	GNOMEUIINFO_MENU_SELECT_ALL_ITEM (select_all_cb, NULL),
 	GNOMEUIINFO_END
 };
@@ -892,32 +743,28 @@ init_gui (void)
 	GtkWidget *vbox;
 	GtkWidget *sw;
 	GtkWidget *w;
-	GtkWidget *image;
 	GtkTooltips *tips;
 
 	tips = gtk_tooltips_new ();
 
-        app = gnome_app_new ("archive-generator",
+        app = gnome_app_new ("meat-grinder",
 			     _("GNOME Archive Generator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app),
-				"archive-generator",
-				"archive-generator");
-	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
+				"meat-grinder",
+				"meat-grinder");
+	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
 
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/document-icons/gnome-compressed.png");
-
-        g_signal_connect (G_OBJECT (app), "delete_event",
-			  G_CALLBACK (quit_cb), NULL);
+        g_signal_connect (GTK_OBJECT (app), "destroy",
+			    GTK_SIGNAL_FUNC (quit_cb), NULL);
 
 	/*set up the menu*/
-
         gnome_app_create_menus (GNOME_APP (app), grinder_menu);
 
 	vbox = gtk_vbox_new (FALSE, 5);
 	gtk_widget_show (vbox);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_set_size_request (sw, 250, 150);
+	gtk_widget_set_usize (sw, 250, 150);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
@@ -927,13 +774,6 @@ init_gui (void)
 	icon_list = gnome_icon_list_new (/*evil*/66, NULL, 0);
 	gnome_icon_list_set_selection_mode  (GNOME_ICON_LIST (icon_list),
 					     GTK_SELECTION_MULTIPLE);
-
-	g_signal_connect (G_OBJECT (icon_list), "select_icon",
-			  G_CALLBACK (icon_select_cb), NULL);	
-
-	g_signal_connect (G_OBJECT (icon_list), "unselect_icon",
-			  G_CALLBACK (icon_unselect_cb), NULL);	
-
 	gtk_widget_show (icon_list);
 	gtk_container_add (GTK_CONTAINER (sw), icon_list);
 
@@ -950,13 +790,18 @@ init_gui (void)
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
 	/* tarball icon */
-	compress_button = archive_button_new_with_image (_("_Create Archive"), 
-							 compress_icon);
+	compress_button = gtk_button_new ();
 	gtk_widget_show (compress_button);
-
+	w = NULL;
+	if (compress_icon != NULL)
+		w = gtk_image_new_from_file (compress_icon);
+	if (w == NULL)
+		w = gtk_label_new (_("Archive"));
+	gtk_widget_show (w);
+	gtk_container_add (GTK_CONTAINER (compress_button), w);
 	gtk_box_pack_start (GTK_BOX (hbox), compress_button, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (compress_button), "clicked",
-			  G_CALLBACK (archive_cb), NULL);
+	g_signal_connect (GTK_OBJECT (compress_button), "clicked",
+			    GTK_SIGNAL_FUNC (archive_cb), NULL);
 	gtk_tooltips_set_tip (tips, compress_button,
 			      _("Drag this button to the destination where you "
 				"want the archive to be created or press it to "
@@ -964,10 +809,6 @@ init_gui (void)
 			      NULL);
 
 	gtk_widget_set_sensitive (compress_button, FALSE);
-	gtk_widget_set_sensitive (file_menu[1].widget, FALSE);
-	gtk_widget_set_sensitive (edit_menu[0].widget, FALSE);
-	gtk_widget_set_sensitive (edit_menu[1].widget, FALSE);
-	gtk_widget_set_sensitive (edit_menu[2].widget, FALSE);
 
 	/* setup dnd */
 	gtk_drag_source_set (compress_button,
@@ -975,10 +816,11 @@ init_gui (void)
 			     drag_targets, n_drag_targets,
 			     GDK_ACTION_COPY);
 	/* just in case some wanker like nautilus took our image */
-	g_signal_connect (G_OBJECT (compress_button), "drag_begin",
-			  G_CALLBACK (start_temporary), NULL);
-	g_signal_connect (G_OBJECT (compress_button), "drag_data_get",
-			  G_CALLBACK (drag_data_get), NULL);
+	g_signal_connect (GTK_OBJECT (compress_button), "drag_begin",
+			    GTK_SIGNAL_FUNC (start_temporary), NULL);
+	g_signal_connect (GTK_OBJECT (compress_button), "drag_data_get",
+			    GTK_SIGNAL_FUNC (drag_data_get), NULL);
+
 
 	status_label = gtk_label_new ("");
 	gtk_label_set_justify (GTK_LABEL (status_label), GTK_JUSTIFY_LEFT);
@@ -993,8 +835,8 @@ init_gui (void)
 			   GTK_DEST_DEFAULT_ALL,
 			   drop_targets, n_drop_targets,
 			   GDK_ACTION_LINK);
-	g_signal_connect (G_OBJECT (app), "drag_data_received",
-			  G_CALLBACK (drag_data_received), NULL);
+	g_signal_connect (GTK_OBJECT (app), "drag_data_received",
+			    GTK_SIGNAL_FUNC (drag_data_received), NULL);
 
 	gnome_app_set_contents (GNOME_APP (app), vbox);
 
@@ -1011,50 +853,22 @@ got_signal (gint sig)
 	kill (getpid (), sig);
 }
 
-static gint
-save_session (GnomeClient *client, gint phase,
- 	      GnomeRestartStyle save_style, gint shutdown,
- 	      GnomeInteractStyle interact_style, gint fast,
- 	      gpointer client_data)
-{
- 	gchar *argv[] = { NULL };
- 
- 	argv[0] = (gchar *) client_data;
- 	gnome_client_set_clone_command (client, 1, argv);
- 	gnome_client_set_restart_command (client, 1, argv);
- 
- 	return TRUE;
-}
- 
-static gint
-die (GnomeClient *client, gpointer client_data)
-{
-	gtk_main_quit ();
-}
-
 gint
 main (gint argc, gchar *argv [])
 {
 	gint i;
 	poptContext ctx;
 	const gchar **files;
-	GnomeClient *client;
 	
 	/* Initialize the i18n stuff */
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_program_init ("meat-grinder", VERSION, LIBGNOMEUI_MODULE,
-				    argc, argv, GNOME_PARAM_POPT_TABLE,
-				    &options,GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
-
-	client = gnome_master_client ();
-
-	g_signal_connect (client, "save_yourself",
-			  G_CALLBACK (save_session), (gpointer)argv[0]);
-
-	g_signal_connect (client, "die", G_CALLBACK (die), NULL);
+	gnome_init_with_popt_table ("meat-grinder", VERSION,
+				    argc, argv, NULL, 0, &ctx);
+	/* no icon yet */
+	/*gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-meat-grinder.png");*/
 
 	file_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mc/i-regular.png", TRUE, NULL);
 	if (file_icon == NULL)
@@ -1076,7 +890,7 @@ main (gint argc, gchar *argv [])
 	if (folder_icon == NULL)
 		folder_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-unknown.png", TRUE, NULL);
 
-	compress_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "document-icons/gnome-compressed.png", TRUE, NULL);
+	compress_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-compressed.png", TRUE, NULL);
 	if (compress_icon == NULL)
 		compress_icon = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "nautilus/gnome-compressed.png", TRUE, NULL);
 	if (compress_icon == NULL)
@@ -1095,30 +909,11 @@ main (gint argc, gchar *argv [])
 			  "This is the program used for creating archives."));
 		exit (1);
 	}
-	sh_prog = g_find_program_in_path ("sh");
-	if (sh_prog == NULL) {
-		g_print("Cannot find the shell (sh) program! Aborting");
-		exit (1);
-	}
-
-	gzip_prog = g_find_program_in_path ("gzip");
-	if (gzip_prog == NULL) {
-		g_print("Cannot find the compression (gzip) program!\n"
-			 "This is the program used for compressing archives.\n");
-		exit (1);
-	}
-
-	ctx = poptGetContext (PACKAGE, argc, (const char **) argv, &options, 0);
 
 	files = poptGetArgs (ctx);
 
 	init_gui ();
 
-	create_archive_widget = file_menu[1].widget;
-	remove_widget = edit_menu[0].widget;
-	clear_widget = edit_menu[1].widget;
-	selectall_widget = edit_menu[2].widget;
-
 	file_ht = g_hash_table_new (g_str_hash, g_str_equal);
 
 	gnome_icon_list_freeze (GNOME_ICON_LIST (icon_list));
@@ -1143,10 +938,6 @@ main (gint argc, gchar *argv [])
 	gtk_main ();
 
 	cleanup_temporary ();
-
-	g_free(tar_prog);
-	g_free(sh_prog);
-	g_free(gzip_prog);
 	
 	return 0;
 }
